from setuptools import setup

setup(
      name = "fc_bigdatal",
      version = "1.0"  ,
      py_modules = ["fc_xd_bigdata"],
      author = "大数据1",
      author_email = "fc@bigdata.com",
      description = "大数据1"
)